@@ -1,2 +1,2 @@
 def test_import_geos5fp():
-    import geos5fp
+    import GEOS5FP
